@@ -27,22 +27,22 @@ addTopoJSON <- function(map, topojson, layerId = NULL, group = NULL,
   options = pathOptions()
 ) {
   map$dependencies <- c(map$dependencies, leafletOmnivoreDependencies())
-  options = c(options, list(
+  options <- c(options, list(
     stroke = stroke, color = color, weight = weight, opacity = opacity,
     fill = fill, fillColor = fillColor, fillOpacity = fillOpacity,
     dashArray = dashArray, smoothFactor = smoothFactor, noClip = noClip
   ))
-  invokeMethod(map, getMapData(map), 'addTopoJSON', topojson, layerId, group, options)
+  invokeMethod(map, getMapData(map), "addTopoJSON", topojson, layerId, group, options)
 }
 
 #' @rdname remove
 #' @export
 removeTopoJSON <- function(map, layerId) {
-  invokeMethod(map, getMapData(map), 'removeTopoJSON', layerId)
+  invokeMethod(map, getMapData(map), "removeTopoJSON", layerId)
 }
 
 #' @rdname remove
 #' @export
 clearTopoJSON <- function(map) {
-  invokeMethod(map, NULL, 'clearTopoJSON')
+  invokeMethod(map, NULL, "clearTopoJSON")
 }
